@@ -22,7 +22,7 @@ def steinalp(f,numfac):
     while nmshape > 1:
         nmshape = nmshape / frav.shape[ishape]
         ishape = ishape + 1
-    newshape = [nmshape] 
+    newshape = [2**numfac] 
     if len(frav.shape) > ishape:
         newshape = newshape +list(frav.shape[ishape:])
 
