@@ -58,7 +58,6 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
     else:
         if (outcoords == None):
             outcoords = cocosel
-    print(cocosel)
 
     # remove NA (None) values if specified
     # would be more elegant if we could simply do cosel = cosel[cosel!=None], but None inside [] does strange things
@@ -84,40 +83,40 @@ def datacosel(indata, cocosel = None, coords = None, outcoords = None, \
     return(list([array(dataout), array(outcoords)]))
 
 
-# aim: build an array (boolean) selection from indices of any dimension
-# the coordinates from which elements of the multi-dim matrix are selected
-#      wrapper function for a more advanced array selection
-# SHAPE: shape of the multidim-matrix
-# SEL: list indices of each dimension of a matrix we want to selected. e.g. with SEL=[[0,1,2],[0],[0]],
-# we select a 3x1x1 matrix 
-# usage: datasel = data[arraysel([[0,1,2],[0,2,4],[22,23]],SHAPE=shape(data))
-def arraysel(SEL,SHAPE = None):
-    if (SHAPE == None):
-        SHAPE = []
-        for eSEL in SEL:
-            SHAPE.append(max(eSEL) + 1 )
-    lfirst = True
-    #ntruefalse: the matrix we want to construct, which can be used to select the data.
-    ntruefalse = True
-    for axidx,dimsize in reversed(list(enumerate(SHAPE))):
-        # build a boolean array for current dimension
-        curdimarray = (zeros(dimsize) == 1)
-        for element in SEL[axidx]: 
-            if (element != None): # workaround: data[None] selects all data
-                curdimarray[element] = True 
-        otruefalse = ntruefalse
-        # for the first dimension, we initialize ntruefalse(shape)
-        if (lfirst):
-            ntruefalseshape = dimsize
-            lfirst = False
-        else:
-            ntruefalseshape = list(ntruefalse.shape)
-            ntruefalseshape.insert(0,dimsize)
-        ntruefalse = (zeros(ntruefalseshape) == 1)
-        for ielement,element in enumerate(curdimarray):
-            if (element == True):
-                ntruefalse[ielement] = otruefalse
-            else:
-                ntruefalse[ielement] = False
-    return ntruefalse
+# # aim: build an array (boolean) selection from indices of any dimension
+# # the coordinates from which elements of the multi-dim matrix are selected
+# #      wrapper function for a more advanced array selection
+# # SHAPE: shape of the multidim-matrix
+# # SEL: list indices of each dimension of a matrix we want to selected. e.g. with SEL=[[0,1,2],[0],[0]],
+# # we select a 3x1x1 matrix 
+# # usage: datasel = data[arraysel([[0,1,2],[0,2,4],[22,23]],SHAPE=shape(data))
+# def arraysel(SEL,SHAPE = None):
+#     if (SHAPE == None):
+#         SHAPE = []
+#         for eSEL in SEL:
+#             SHAPE.append(max(eSEL) + 1 )
+#     lfirst = True
+#     #ntruefalse: the matrix we want to construct, which can be used to select the data.
+#     ntruefalse = True
+#     for axidx,dimsize in reversed(list(enumerate(SHAPE))):
+#         # build a boolean array for current dimension
+#         curdimarray = (zeros(dimsize) == 1)
+#         for element in SEL[axidx]: 
+#             if (element != None): # workaround: data[None] selects all data
+#                 curdimarray[element] = True 
+#         otruefalse = ntruefalse
+#         # for the first dimension, we initialize ntruefalse(shape)
+#         if (lfirst):
+#             ntruefalseshape = dimsize
+#             lfirst = False
+#         else:
+#             ntruefalseshape = list(ntruefalse.shape)
+#             ntruefalseshape.insert(0,dimsize)
+#         ntruefalse = (zeros(ntruefalseshape) == 1)
+#         for ielement,element in enumerate(curdimarray):
+#             if (element == True):
+#                 ntruefalse[ielement] = otruefalse
+#             else:
+#                 ntruefalse[ielement] = False
+#     return ntruefalse
  
